==> qtjambi-scxml-debuginfo-macos-5.15.20.jar: sources/QtJambiScxml/QScxmlCompiler_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScxml/qscxmlcompiler.h>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qxmlstream.h>
#include <QtScxml/qscxmlerror.h>
#include <QtScxml/qscxmlstatemachine.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScxmlCompiler(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScxmlCompiler")
    QScxmlCompiler *_ptr = reinterpret_cast<QScxmlCompiler *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScxmlCompiler(QScxmlCompiler)
void __qt_construct_QScxmlCompiler_cref_QScxmlCompiler(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScxmlCompiler(QScxmlCompiler)")
    jobject other0 = __java_arguments[0].l;
    const QScxmlCompiler& __qt_other0 = qtjambi_cast<const QScxmlCompiler& >(__jni_env, other0);
    QScxmlCompiler *__qt_this = new(__qtjambi_ptr) QScxmlCompiler(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScxmlCompiler::QScxmlCompiler(QScxmlCompiler)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_initialize_1native__Lio_qt_scxml_QScxmlCompiler_2Lio_qt_scxml_QScxmlCompiler_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlCompiler::QScxmlCompiler(QScxmlCompiler)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlCompiler_cref_QScxmlCompiler, sizeof(QScxmlCompiler), typeid(QScxmlCompiler), false, &deleter_QScxmlCompiler, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QScxmlCompiler(QXmlStreamReader*)
void __qt_construct_QScxmlCompiler_QXmlStreamReader_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScxmlCompiler(QXmlStreamReader*)")
    jobject xmlReader0 = __java_arguments[0].l;
    QXmlStreamReader* __qt_xmlReader0 = qtjambi_cast<QXmlStreamReader* >(__jni_env, xmlReader0);
    QScxmlCompiler *__qt_this = new(__qtjambi_ptr) QScxmlCompiler(__qt_xmlReader0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScxmlCompiler::QScxmlCompiler(QXmlStreamReader*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_initialize_1native__Lio_qt_scxml_QScxmlCompiler_2Lio_qt_core_QXmlStreamReader_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject xmlReader0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlCompiler::QScxmlCompiler(QXmlStreamReader*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = xmlReader0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlCompiler_QXmlStreamReader_ptr, sizeof(QScxmlCompiler), typeid(QScxmlCompiler), false, &deleter_QScxmlCompiler, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScxmlCompiler
void __qt_destruct_QScxmlCompiler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScxmlCompiler")
    reinterpret_cast<QScxmlCompiler*>(ptr)->~QScxmlCompiler();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScxmlCompiler::compile()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_compile_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::compile()", __qt_this)
        QScxmlStateMachine* __qt_return_value = __qt_this->compile();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::errors()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_errors_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::errors()const", __qt_this)
        QVector<QScxmlError> __qt_return_value = __qt_this->errors();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::fileName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_fileName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::fileName()const", __qt_this)
        QString __qt_return_value = __qt_this->fileName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::loader()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_loader_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::loader()const", __qt_this)
        QScxmlCompiler::Loader* __qt_return_value = __qt_this->loader();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::setFileName(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_setFileName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::setFileName(QString)", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString>(__jni_env, fileName0);
        __qt_this->setFileName(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScxmlCompiler::setLoader(QScxmlCompiler::Loader*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_setLoader_1native_1QScxmlCompiler_1Loader_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID newLoader0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::setLoader(QScxmlCompiler::Loader*)", __qt_this)
        QScxmlCompiler::Loader* __qt_newLoader0 = QtJambiAPI::interfaceFromNativeId<QScxmlCompiler::Loader>(newLoader0);
        __qt_this->setLoader(__qt_newLoader0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QScxmlCompiler(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScxmlCompiler(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QScxmlCompiler>("QScxmlCompiler", "io/qt/scxml/QScxmlCompiler");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScxmlCompiler, {
        ConstructorInfo(&__qt_construct_QScxmlCompiler_cref_QScxmlCompiler, "Lio/qt/scxml/QScxmlCompiler;")
       ,ConstructorInfo(&__qt_construct_QScxmlCompiler_QXmlStreamReader_ptr, "Lio/qt/core/QXmlStreamReader;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScxmlCompiler);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-scxml-debuginfo-macos-6.5.3.jar: sources/QtJambiScxml/QScxmlCompiler_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScxml/qscxmlcompiler.h>
#include <QtCore/QVariant>
#include <QtCore/qxmlstream.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtCore/QList>
#include <QtScxml/qscxmlerror.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScxmlCompiler(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScxmlCompiler")
    QScxmlCompiler *_ptr = reinterpret_cast<QScxmlCompiler *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScxmlCompiler(QXmlStreamReader*)
void __qt_construct_QScxmlCompiler_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScxmlCompiler(QXmlStreamReader*)")
    jobject xmlReader0 = __java_arguments[0].l;
    QXmlStreamReader* __qt_xmlReader0 = qtjambi_cast<QXmlStreamReader* >(__jni_env, xmlReader0);
    QScxmlCompiler *__qt_this = new(__qtjambi_ptr) QScxmlCompiler(__qt_xmlReader0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QScxmlCompiler
void __qt_destruct_QScxmlCompiler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScxmlCompiler")
    reinterpret_cast<QScxmlCompiler*>(ptr)->~QScxmlCompiler();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScxmlCompiler::QScxmlCompiler(QXmlStreamReader*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_initialize_1native__Lio_qt_scxml_QScxmlCompiler_2Lio_qt_core_QXmlStreamReader_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject xmlReader0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlCompiler::QScxmlCompiler(QXmlStreamReader*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = xmlReader0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlCompiler_0, sizeof(QScxmlCompiler), typeid(QScxmlCompiler), false, &deleter_QScxmlCompiler, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScxmlCompiler::compile()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_compile_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::compile()", __qt_this)
        QScxmlStateMachine* __qt_return_value = __qt_this->compile();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::errors()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_errors_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::errors()const", __qt_this)
        QList<QScxmlError> __qt_return_value = __qt_this->errors();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::fileName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_fileName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::fileName()const", __qt_this)
        QString __qt_return_value = __qt_this->fileName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::loader()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_loader_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::loader()const", __qt_this)
        QScxmlCompiler::Loader* __qt_return_value = __qt_this->loader();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScxmlCompiler::setFileName(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_setFileName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::setFileName(QString)", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString >(__jni_env, fileName0);
        __qt_this->setFileName(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScxmlCompiler::setLoader(QScxmlCompiler::Loader*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_setLoader_1native_1QScxmlCompiler_1Loader_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID newLoader0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlCompiler::setLoader(QScxmlCompiler::Loader*)", __qt_this)
        QScxmlCompiler::Loader* __qt_newLoader0 = QtJambiAPI::interfaceFromNativeId<QScxmlCompiler::Loader>(newLoader0);
        __qt_this->setLoader(__qt_newLoader0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlCompiler_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScxmlCompiler *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlCompiler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QScxmlCompiler(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScxmlCompiler(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QScxmlCompiler>("QScxmlCompiler", "io/qt/scxml/QScxmlCompiler");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScxmlCompiler, {
        ConstructorInfo(&__qt_construct_QScxmlCompiler_0, "Lio/qt/core/QXmlStreamReader;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScxmlCompiler);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
